@@ -6,7 +6,7 @@ __author__ = ["tom van mele"]
 __copyright__ = "Block Research Group - ETH Zurich"
 __license__ = "MIT License"
 __email__ = "van.mele@arch.ethz.ch"
-__version__ = "0.3.0"
+__version__ = "0.4.1"
 
 
 HERE = os.path.dirname(__file__)
@@ -31,4 +31,4 @@ except Exception:
     util.find_library = new_util_find_library
 
 
-__all__ = ["HOME", "DATA", "DOCS", "TEMP", "DATA_VIEW", "register"]
+__all__ = ["HOME", "DATA", "DOCS", "TEMP", "DATA_OBJECT", "register"]
