@@ -9,6 +9,13 @@ from compas.geometry import Box
 from compas.geometry import Sphere
 from compas.geometry import Torus
 from compas.geometry import Cylinder
+from compas.geometry import Plane
+from compas.geometry import Circle
+from compas.geometry import Ellipse
+from compas.geometry import Polygon
+from compas.geometry import Cone
+from compas.geometry import Capsule
+from compas.geometry import Polyhedron
 
 from ..shapes import Arrow
 from ..shapes import Text
@@ -33,6 +40,13 @@ from .textobject import TextObject
 from .collectionobject import CollectionObject
 from .gridobject import GridObject  # noqa: F401
 from .cylinderobject import CylinderObject
+from .planeobject import PlaneObject
+from .circleobject import CircleObject
+from .ellipseobject import EllipseObject
+from .polygonobject import PolygonObject
+from .coneobject import ConeObject
+from .capsuleobject import CapsuleObject
+from .polyhedronobject import PolyhedronObject
 
 Object.register(Point, PointObject)
 Object.register(Pointcloud, PointcloudObject)
@@ -49,6 +63,13 @@ Object.register(Torus, TorusObject)
 Object.register(Arrow, ArrowObject)
 Object.register(Collection, CollectionObject)
 Object.register(Cylinder, CylinderObject)
+Object.register(Plane, PlaneObject)
+Object.register(Circle, CircleObject)
+Object.register(Ellipse, EllipseObject)
+Object.register(Polygon, PolygonObject)
+Object.register(Cone, ConeObject)
+Object.register(Capsule, CapsuleObject)
+Object.register(Polyhedron, PolyhedronObject)
 Object.register(Text, TextObject)
 
 try:
@@ -57,3 +78,11 @@ except ModuleNotFoundError:
     pass
 else:
     Object.register(Block, MeshObject)
+
+try:
+    from compas_occ.geometry import NurbsSurface
+    from .nurbssurfaceobject import NurbsSurfaceObject
+except ModuleNotFoundError:
+    pass
+else:
+    Object.register(NurbsSurface, NurbsSurfaceObject)
